@@ -156,10 +156,10 @@ def get_name_and_relative_path(
 ) -> Tuple[str, Path]:
     if syspath_sleuth_path:
         sleuth_name = syspath_sleuth_path.name
-        sleuth_path: Path = get_relative_path(syspath_sleuth_path)
+        sleuth_path: Path = get_relative_path(customize_path)
     else:
         sleuth_name = SysPathSleuth.__name__
-        sleuth_path: Path = SysPathSleuth.relative_path(customize_path)
+        sleuth_path = SysPathSleuth.relative_path(customize_path)
     return sleuth_name, sleuth_path
 
 
@@ -269,6 +269,7 @@ def syspath_sleuth_main(inject: bool, custom: str, verbose: bool):
         for handler in sleuth_logger.handlers:
             handler.setLevel(logging.INFO)
 
+    # pylint: disable=broad-except
     try:
         if inject:
             inject_sleuth(custom_path)
@@ -294,5 +295,5 @@ def syspath_sleuth_main(inject: bool, custom: str, verbose: bool):
                 pass
 
             uninstall_sleuth()
-    except Exception as e:
-        error_logger.error(f"{'Inject' if inject else 'Uninstall'} failed: {e}")
+    except Exception as ex:
+        error_logger.error("%s failed: %s", 'Inject' if inject else 'Uninstall', ex)
